==> Postcode-1.1.tar.gz: Postcode/lang/ext/nb_NO.php <==
<?php
$lang['changelog'] = 'Endringslogg';
$lang['country'] = 'Land';
$lang['error_duplicatepostal'] = 'En duplikat postnummer oppf&oslash;ring ble funnet p&aring; linje %d';
$lang['error_empty_delimiter'] = 'Du m&aring; angi et skilletegn';
$lang['error_empty_fieldmap'] = 'Du m&aring; angi et feltkart';
$lang['error_fileupload'] = 'Problem med opplasting av importfil';
$lang['error_invalidmap'] = 'Feltkartet du oppga er ugyldig eller inneholder en feil';
$lang['error_insertfailed'] = 'Feil p&aring; linje %d, innsetting i database feilet';
$lang['error_lookup_failed'] = 'Oppslag av postnummer mislyktes';
$lang['error_nofile'] = 'Ingen importfil ble spesifisert';
$lang['error_numfields'] = 'Feil p&aring; linje% d, ikke samsvarende antall felt';
$lang['error_readfile'] = 'Et problem oppstod ved fors&oslash;k p&aring; &aring; lese den opplastede filen';
$lang['friendlyname'] = 'Postnummer oppslag';
$lang['help'] = 'TODO ';
$lang['import'] = 'Import ';
$lang['import_policy_error'] = 'Rapportfeil';
$lang['import_policy_ignore'] = 'Stille ignorering';
$lang['import_policy_overwrite'] = 'Erstatt opprinnelige verdier';
$lang['info_delimeter'] = 'Oppgi tegn som skiller hver kolonne i filen. Bruk strengen [TAB] for &aring; indikere tabulatortegn.';
$lang['info_fieldmap'] = 'This field defines the map between required fields and import file columns.  The format should be of the form &quot;name=number&quot; where the name is one of the possible names below, and the number is a column number (starting from 1).<br/><br/>
<h5>Field Names:</h5>
<ul>
  <li>country - the country code</li>
  <li>postal - the postal code</li>
  <li>placename - A logical place name</li>
  <li>latitude - the latitude in decimal format</li>
  <li>longitude - the longitude in decimal format</li>
</ul>';
$lang['latitude'] = 'Bredegrad(Latitude)';
$lang['longitude'] = 'Lengdegrad(Longitude)';
$lang['lookup'] = 'Oppslag';
$lang['lookup_successful'] = 'Vellykket oppslag';
$lang['moddescription'] = 'En enkel modul for &aring; tillate konvertering av post- eller zip-nummer til breddegrad og lengdegrad basert p&aring; geonames tjenesten';
$lang['msg_import_numimported'] = 'Importerte %d poster';
$lang['opmode_dbfirst'] = 'Database f&oslash;rst - s&aring; online';
$lang['opmode_dbfirst_cache'] = 'Database f&oslash;rst - s&aring; online med mellomlagring';
$lang['opmode_dbonly'] = 'Kun database';
$lang['opmode_onlineonly'] = 'Kun online oppslag';
$lang['place_name'] = 'STedsnavn';
$lang['postal_code'] = 'Postnummer / Zip-kode';
$lang['postinstall'] = 'Postcode modulen har blitt installert';
$lang['postuninstall'] = 'Postcode modulen har blitt avinstallert';
$lang['preferences'] = 'Innstillinger';
$lang['prev'] = 'Tilbake';
$lang['prompt_assume_country'] = 'Om ikke spesifisert s&aring; annta dette land';
$lang['prompt_delimiter'] = 'Adskiller';
$lang['prompt_duplicate_policy'] = 'Regler for duplikate postnummer';
$lang['prompt_fieldmap'] = 'Feltkart';
$lang['prompt_file'] = 'Fil';
$lang['prompt_operation_mode'] = 'Funksjonsmodus';
$lang['really_uninstall'] = 'Er du sikker p&aring; at du vil gj&oslash;re dette?';
$lang['submit'] = 'Send';
$lang['utmz'] = '156861353.1245190196.1444.36.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/download_themes.html';
$lang['utma'] = '156861353.179052623084110100.1210423577.1246202489.1246207072.1506';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.3.10.1246207072';
?>

==> Postcode-1.1.1.tar.gz: Postcode/lang/ext/nb_NO.php <==
<?php
$lang['changelog'] = 'Endringslogg';
$lang['country'] = 'Land';
$lang['error_duplicatepostal'] = 'En duplikat postnummer oppf&oslash;ring ble funnet p&aring; linje %d';
$lang['error_empty_delimiter'] = 'Du m&aring; angi et skilletegn';
$lang['error_empty_fieldmap'] = 'Du m&aring; angi et feltkart';
$lang['error_fileupload'] = 'Problem med opplasting av importfil';
$lang['error_invalidmap'] = 'Feltkartet du oppga er ugyldig eller inneholder en feil';
$lang['error_insertfailed'] = 'Feil p&aring; linje %d, innsetting i database feilet';
$lang['error_lookup_failed'] = 'Oppslag av postnummer mislyktes';
$lang['error_nofile'] = 'Ingen importfil ble spesifisert';
$lang['error_numfields'] = 'Feil p&aring; linje% d, ikke samsvarende antall felt';
$lang['error_readfile'] = 'Et problem oppstod ved fors&oslash;k p&aring; &aring; lese den opplastede filen';
$lang['friendlyname'] = 'Postnummer oppslag';
$lang['help'] = 'TODO ';
$lang['import'] = 'Import ';
$lang['import_policy_error'] = 'Rapportfeil';
$lang['import_policy_ignore'] = 'Stille ignorering';
$lang['import_policy_overwrite'] = 'Erstatt opprinnelige verdier';
$lang['info_delimeter'] = 'Oppgi tegn som skiller hver kolonne i filen. Bruk strengen [TAB] for &aring; indikere tabulatortegn.';
$lang['info_effective_chars'] = 'Noen regioner <em>(Canada)</em> har kanskje lange postnummer for &aring; identifisere spesifikke omr&aring;der, men databasen inneholder kun n&oslash;kler for prefikser av en viss lengde. Dette feltet vil effektivt forkorte det oppgitte postnummeret til antall effektive tegn f&oslash;r foresp&oslash;rselen sendes til databasen.';
$lang['info_fieldmap'] = 'This field defines the map between required fields and import file columns.  The format should be of the form &quot;name=number&quot; where the name is one of the possible names below, and the number is a column number (starting from 1).<br/><br/>
<h5>Field Names:</h5>
<ul>
  <li>country - the country code</li>
  <li>postal - the postal code</li>
  <li>placename - A logical place name</li>
  <li>latitude - the latitude in decimal format</li>
  <li>longitude - the longitude in decimal format</li>
</ul>';
$lang['latitude'] = 'Bredegrad(Latitude)';
$lang['longitude'] = 'Lengdegrad(Longitude)';
$lang['lookup'] = 'Oppslag';
$lang['lookup_successful'] = 'Vellykket oppslag';
$lang['moddescription'] = 'En enkel modul for &aring; tillate konvertering av post- eller zip-nummer til breddegrad og lengdegrad basert p&aring; geonames tjenesten';
$lang['msg_import_numimported'] = 'Importerte %d poster';
$lang['opmode_dbfirst'] = 'Database f&oslash;rst - s&aring; online';
$lang['opmode_dbfirst_cache'] = 'Database f&oslash;rst - s&aring; online med mellomlagring';
$lang['opmode_dbonly'] = 'Kun database';
$lang['opmode_onlineonly'] = 'Kun online oppslag';
$lang['place_name'] = 'STedsnavn';
$lang['postal_code'] = 'Postnummer / Zip-kode';
$lang['postinstall'] = 'Postcode modulen har blitt installert';
$lang['postuninstall'] = 'Postcode modulen har blitt avinstallert';
$lang['preferences'] = 'Innstillinger';
$lang['prev'] = 'Tilbake';
$lang['prompt_assume_country'] = 'Om ikke spesifisert s&aring; annta dette land';
$lang['prompt_delimiter'] = 'Adskiller';
$lang['prompt_duplicate_policy'] = 'Regler for duplikate postnummer';
$lang['prompt_effective_chars'] = 'Antall effektive tegn i postnummer s&oslash;k';
$lang['prompt_fieldmap'] = 'Feltkart';
$lang['prompt_file'] = 'Fil';
$lang['prompt_operation_mode'] = 'Funksjonsmodus';
$lang['really_uninstall'] = 'Er du sikker p&aring; at du vil gj&oslash;re dette?';
$lang['submit'] = 'Send';
$lang['utmz'] = '156861353.1283287349.3202.74.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utma'] = '156861353.179052623084110100.1210423577.1284228895.1284233799.3248';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1284233799';
?>
